@@ -7,8 +7,10 @@ You should see the RGBA test image correctly rendered.  Press ESC to
 end the test.
 '''
 
+from __future__ import print_function
+
 __docformat__ = 'restructuredtext'
-__version__ = '$Id: MATRIX_RGBA.py 1768 2008-02-17 12:45:54Z Alex.Holkner $'
+__version__ = '$Id$'
 
 import unittest
 import base_load
@@ -21,7 +23,7 @@ class TEST_MATRIX_RGBA(base_load.TestLoad):
     
     def load_image(self):
         if not gl_info.have_extension('GL_ARB_imaging'):
-            print 'GL_ARB_imaging is not present, skipping test.'
+            print('GL_ARB_imaging is not present, skipping test.')
             self.has_exit = True
         else:
             # Load image as usual then rearrange components
